@@ -10,6 +10,7 @@ import (
 	"github.com/charmbracelet/bubbles/spinner"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
+	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
 )
 
 var program *tea.Program
@@ -29,7 +30,7 @@ type loadMsg []*Asset
 
 type zipMsg []byte
 
-type successMsg int
+type successMsg []string
 
 type errMsg error
 
@@ -69,12 +70,13 @@ const (
 )
 
 type main struct {
-	spinner spinner.Model
-	list    *list.Model
-	system  bool
-	font    string
-	state   state
-	err     error
+	spinner  spinner.Model
+	list     *list.Model
+	system   bool
+	font     string
+	state    state
+	err      error
+	families []string
 }
 
 func (m *main) buildFontList(nerdFonts []*Asset) {
@@ -97,12 +99,13 @@ func (m *main) buildFontList(nerdFonts []*Asset) {
 }
 
 func getFontsList() {
-	nerdFonts, err := Nerds()
+	fonts, err := Fonts()
 	if err != nil {
 		program.Send(errMsg(err))
 		return
 	}
-	program.Send(loadMsg(nerdFonts))
+
+	program.Send(loadMsg(fonts))
 }
 
 func downloadFontZip(location string) {
@@ -124,12 +127,12 @@ func installLocalFontZIP(zipFile string, user bool) {
 }
 
 func installFontZIP(zipFile []byte, user bool) {
-	err := InstallZIP(zipFile, user)
+	families, err := InstallZIP(zipFile, user)
 	if err != nil {
 		program.Send(errMsg(err))
 		return
 	}
-	program.Send(successMsg(0))
+	program.Send(successMsg(families))
 }
 
 func (m *main) Init() tea.Cmd {
@@ -216,6 +219,7 @@ func (m *main) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 
 	case successMsg:
 		m.state = done
+		m.families = msg
 		return m, tea.Quit
 
 	case errMsg:
@@ -228,6 +232,10 @@ func (m *main) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		return m, cmd
 	}
 
+	if m.list == nil {
+		return m, nil
+	}
+
 	lst, cmd := m.list.Update(msg)
 	m.list = &lst
 	return m, cmd
@@ -239,19 +247,29 @@ func (m *main) View() string {
 	}
 	switch m.state {
 	case getFonts:
-		return textStyle.Render(fmt.Sprintf("%s Downloading font list", m.spinner.View()))
+		return textStyle.Render(fmt.Sprintf("%s Downloading font list%s", m.spinner.View(), terminal.StartProgress()))
 	case selectFont:
-		return "\n" + m.list.View()
+		return fmt.Sprintf("\n%s%s", m.list.View(), terminal.StopProgress())
 	case downloadFont:
-		return textStyle.Render(fmt.Sprintf("%s Downloading %s", m.spinner.View(), m.font))
+		return textStyle.Render(fmt.Sprintf("%s Downloading %s%s", m.spinner.View(), m.font, terminal.StartProgress()))
 	case unzipFont:
 		return textStyle.Render(fmt.Sprintf("%s Extracting %s", m.spinner.View(), m.font))
 	case installFont:
 		return textStyle.Render(fmt.Sprintf("%s Installing %s", m.spinner.View(), m.font))
 	case quit:
-		return textStyle.Render("No need to install a new font? That's cool.")
+		return textStyle.Render(fmt.Sprintf("No need to install a new font? That's cool.%s", terminal.StopProgress()))
 	case done:
-		return textStyle.Render(fmt.Sprintf("Successfully installed %s 🚀", m.font))
+		var builder strings.Builder
+		builder.WriteString(fmt.Sprintf("Successfully installed %s 🚀\n\n%s", m.font, terminal.StopProgress()))
+		builder.WriteString("The following font families are now available for configuration:\n")
+		for i, family := range m.families {
+			builder.WriteString(fmt.Sprintf("  • %s", family))
+
+			if i < len(m.families)-1 {
+				builder.WriteString("\n")
+			}
+		}
+		return textStyle.Render(builder.String())
 	}
 	return ""
 }
@@ -264,6 +282,6 @@ func Run(font string, system bool) {
 	program = tea.NewProgram(main)
 	if _, err := program.Run(); err != nil {
 		print("Error running program: %v", err)
-		os.Exit(1)
+		os.Exit(70)
 	}
 }
