@@ -1,6 +1,7 @@
 package prompt
 
 import (
+	"slices"
 	"strings"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
@@ -9,6 +10,18 @@ import (
 )
 
 func (e *Engine) Tooltip(tip string) string {
+	supportedShells := []string{
+		shell.ZSH,
+		shell.CMD,
+		shell.FISH,
+		shell.PWSH,
+		shell.PWSH5,
+		shell.GENERIC,
+	}
+	if !slices.Contains(supportedShells, e.Env.Shell()) {
+		return ""
+	}
+
 	tip = strings.Trim(tip, " ")
 	tooltips := make([]*config.Segment, 0, 1)
 
@@ -35,40 +48,28 @@ func (e *Engine) Tooltip(tip string) string {
 		Alignment: config.Right,
 		Segments:  tooltips,
 	}
+	block.Init(e.Env)
+	if !block.Enabled() {
+		return ""
+	}
+	text, length := e.renderBlockSegments(block)
 
 	switch e.Env.Shell() {
-	case shell.ZSH, shell.CMD, shell.FISH, shell.GENERIC:
-		block.Init(e.Env)
-		if !block.Enabled() {
-			return ""
-		}
-		text, _ := e.renderBlockSegments(block)
-		return text
 	case shell.PWSH, shell.PWSH5:
-		if !block.Enabled() {
+		e.rprompt = text
+		e.currentLineLength = e.Env.Flags().Column
+		space, ok := e.canWriteRightBlock(length, true)
+		if !ok {
 			return ""
 		}
-
-		consoleWidth, err := e.Env.TerminalWidth()
-		if err != nil || consoleWidth == 0 {
-			return ""
-		}
-
-		text, length := e.renderBlockSegments(block)
-
-		space := consoleWidth - e.Env.Flags().Column - length
-		if space <= 0 {
-			return ""
-		}
-		// clear from cursor to the end of the line in case a previous tooltip
-		// is cut off and partially preserved, if the new one is shorter
-		e.write(terminal.ClearAfter())
+		e.write(terminal.SaveCursorPosition())
 		e.write(strings.Repeat(" ", space))
 		e.write(text)
+		e.write(terminal.RestoreCursorPosition())
 		return e.string()
+	default:
+		return text
 	}
-
-	return ""
 }
 
 func (e *Engine) shouldInvokeWithTip(segment *config.Segment, tip string) bool {
